@@ -4,9 +4,16 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.17_04';
+  our $VERSION = '0.17_05';
 
-  use Zydeco authority => 'cpan:SMONFF', version   => $VERSION;
+  use Zydeco
+    authority => 'cpan:SMONFF',
+    # Only possible since Type::Tiny->version 1.011_009 (unstable) In case of
+    # any problem, all
+    #   has attr ( type => xxx ) attr types
+    # should be quotted. See
+    declare => ['Artwork', 'Collector'],
+    version   => $VERSION;
   use Carp;
   use utf8;
 
@@ -38,7 +45,7 @@ package Art::World {
   # Dunno how but the fact of being collected should bump artist reputation
   role Collectionable {
     # Should be an object of type Agent
-    has owner  ( type => 'ArrayRef[Collector]' );
+    has owner  ( type => ArrayRef[ Collector ] );
     has value  ( is   => rw );
     has status (
       enum            => ['for_sale', 'sold'],
@@ -59,25 +66,23 @@ package Art::World {
 
   # I guess it can be consummed by pretty much everything. Like idk, a place
   # have a fame and an artwork too. But it was supposed to be more like an Agent
-  # thing in the beginning
+  # thing in the beginning. Maybe the reputation should be for Agents, and the
+  # Aura only for Artworks and Places
   role Fame {
-    has reputation ( is => rw, type => PositiveOrZeroNum ); #
     # TODO If an Agent work is  collected, it's reputation should go up
     method bump_fame( Num $gain = 1 ) {
-      if ( $self->reputation + $gain >= 0 ) {
-        $self->reputation( $self->reputation + $gain )
+      my $attribute = $self->isa( 'Art::World::Agent' ) ?
+        'reputation' : 'aura';
+      if ( $self->$attribute + $gain >= 0 ) {
+        $self->$attribute( $self->$attribute + $gain )
       } else {
-        carp 'You tried to update reputation to a value smaller ' .
+        carp 'You tried to update ' . $attribute . ' to a value smaller ' .
           'than zero. Nothing changed.';
       }
-      return $self->reputation
+      return $self->$attribute;
     }
   }
 
-  role Space {
-    has space;
-  }
-
   role Exhibit {
     has public;
     has exhibition ( type => ArrayRef );
@@ -89,6 +94,10 @@ package Art::World {
     }
   }
 
+  role Manager {
+    method organize {}
+  }
+
   role Market {
     #has money;
     has price;
@@ -101,6 +110,10 @@ package Art::World {
     }
   }
 
+  role Space {
+    has space;
+  }
+
   role Underground {
     method experiment {
       say "Underground";
@@ -133,6 +146,7 @@ package Art::World {
 
     class Place with Space, Fame {
       class Institution {
+
         class School {
           has student;
           has teachers;
@@ -165,11 +179,11 @@ package Art::World {
     # Should be required but will be moved to the Crudable area
     has id         ( type => Int );
     has name!       ( type => Str );
-
+    has reputation ( is => rw, type => PositiveOrZeroNum );
     class Artist {
 
       has artworks   ( type => ArrayRef );
-      has collectors ( type => 'ArrayRef[Collector]', default => sub { [] } );
+      has collectors ( type => ArrayRef[Collector], default => sub { [] } );
       has collected  ( type => Bool, default => false, is => rw );
       has status (
         enum => [ 'underground', 'homogenic' ],
@@ -203,7 +217,7 @@ package Art::World {
     class Collector with Active, Buyer {
       has money! ( type => Num, is => rw );
       has collection (
-        type    => 'ArrayRef[Artwork, 0 ]',
+        type    => ArrayRef[Artwork, 0 ],
         default => sub { [] },
         is      => rw,
       );
@@ -211,7 +225,17 @@ package Art::World {
 
     class Critic;
 
-    class Curator;
+    class Curator with Manager {
+      has exhibition(
+        type  => ArrayRef,
+      );
+      method select( Artwork $art ) {
+        push @{ $self->exhibition }, $art;
+      }
+      method define( Theory $thematic ) { }
+      method setup( Place $space ) { }
+      method write( Theory $catalog) { }
+    };
 
     class Public {
       method visit {
@@ -227,17 +251,20 @@ package Art::World {
   class Work with Fame {
 
     has creation_date;
-    has creator (
-      is => ro,
+    has creator(
+      is   => ro,
       # Shoul be an ArrayRef of Agents
       type => ArrayRef[ Object ]
     );
 
     has title(
-      is => ro,
+      is   => ro,
       type => Str,
     );
 
+    # Same as Agent->reputation
+    has aura( is => rw, type => PositiveOrZeroNum );
+
     class Article;
 
     class Artwork with Showable, Collectionable  {
@@ -247,10 +274,37 @@ package Art::World {
 
     class Book;
 
-    class Exhibition extends Event;
+    class Exhibition extends Event {
+      has curator! (
+        is   => ro,
+        type => ArrayRef[ Agent ]
+      );
+    };
+  }
+
+  # Looks like the Art::World::Meta toolkit
+  class Meta {
+    method get_class( Object $klass ) {
+      return ref $klass;
+    }
+    # Returns only attributes that are set for a particular object
+    # Inspired by https://www.perlmonks.org/?node_id=1043195
+    method get_set_attributes_only( Object $clazz ) {
+      return keys %{ $clazz };
+    }
+    # Returns even non-set attributes for a particular object
+    # Inspired by https://www.perlmonks.org/?node_id=1043195
+    method get_all_attributes( Object $claxx ) {
+      return keys( %{
+        'Moo'->_constructor_maker_for(
+          $self->get_class( $claxx )
+        )->all_attribute_specs
+      });
+    }
   }
 }
 
+
 1;
 __END__
 
@@ -327,6 +381,11 @@ warning is displayed.
 It is all about offer and demand. Involve a price but should involve more money
 I guess.
 
+=head2 Manager
+
+A role for those who I<take care> of exhibitions and other organizational
+matters.
+
 =head2 Showable
 
 Only an object that does the C<Showable> role can be exhibited. An object should
@@ -390,10 +449,15 @@ They do stuff together. You know, art is not about lonely C<Artists> in their C<
 
 =head2 Curator
 
+A special kind of Agent that I<can> select Artworks, define a thematic, setup
+everything in the space and write a catalog.
+
 =head2 Event
 
 =head2 Exhibition
 
+An C<Event> that is organised by a C<Curator>.
+
 =head2 Gallery
 
 Just another kind of L<C<Place>|Art::World/"Place">, mostly commercial.
